<p align="center">
  <img src="https://github.com/kaliv0/fumus/blob/main/assets/fumus.gif?raw=true" width="400" alt="Fumus">
</p>

# FUMUS

![Python 3.x](https://img.shields.io/badge/python-3.12-blue?style=flat-square&logo=Python&logoColor=white)
[![tests](https://img.shields.io/github/actions/workflow/status/kaliv0/fumus/ci.yml)](https://github.com/kaliv0/fumus/actions/workflows/ci.yml)

[//]: # ([![codecov]&#40;https://codecov.io/gh/kaliv0/fumus/graph/badge.svg?token=7EEG43BL33&#41;]&#40;https://codecov.io/gh/kaliv0/fumus&#41;)

[//]: # ([![docs]&#40;https://readthedocs.org/projects/fumus/badge/?version=latest&#41;]&#40;https://fumus.readthedocs.io/en/latest&#41;)
[![PyPI](https://img.shields.io/pypi/v/fumus.svg)](https://pypi.org/project/fumus/)

[//]: # ([![Downloads]&#40;https://static.pepy.tech/badge/fumus&#41;]&#40;https://pepy.tech/projects/fumus&#41;)

<br><b>Functional-style Streams API library</b><br>